#############
pytest-cython
#############

.. contents::
   :depth: 2

.. include:: ../README.md
    :parser: myst_parser.sphinx_

.. include:: ../CHANGELOG.md
    :parser: myst_parser.sphinx_

.. include:: ../CONTRIBUTING.md
    :parser: myst_parser.sphinx_
